@@ -28,5 +28,5 @@ config = Config(
         )
     ],
     #  AdHoc Clusters should not be setup with scaling strategy.
-    strategy=None,
+    strategy='none',
 )
