@@ -167,6 +167,7 @@ class DataFlowKernel(object):
         self.checkpointed_tasks = 0
         self._checkpoint_timer = None
         self.checkpoint_mode = config.checkpoint_mode
+        self.checkpointable_tasks = []
 
         # the flow control keeps track of executors and provider task states;
         # must be set before executors are added since add_executors calls
@@ -434,20 +435,21 @@ class DataFlowKernel(object):
         self.memoizer.update_memo(task_record, future)
 
         # Cover all checkpointing cases here:
-        # Do we need to checkpoint the task now,
-        # keep it around for one of the other checkpoint
-        # methods, or can we wipe it immediately?
+        # Do we need to checkpoint now, or queue for later,
+        # or do nothing?
         if self.checkpoint_mode == 'task_exit':
             self.checkpoint(tasks=[task_record])
         elif self.checkpoint_mode == 'manual' or \
                 self.checkpoint_mode == 'periodic' or \
                 self.checkpoint_mode == 'dfk_exit':
-            pass
+            with self.checkpoint_lock:
+                self.checkpointable_tasks.append(task_record)
         elif self.checkpoint_mode is None:
-            self.wipe_task(task_id)
+            pass
         else:
             raise RuntimeError(f"Invalid checkpoint mode {self.checkpoint_mode}")
 
+        self.wipe_task(task_id)
         return
 
     def _complete_task(self, task_record: TaskRecord, new_state: States, result: Any) -> None:
@@ -617,14 +619,14 @@ class DataFlowKernel(object):
 
         if self.monitoring is not None and self.monitoring.resource_monitoring_enabled:
             wrapper_logging_level = logging.DEBUG if self.monitoring.monitoring_debug else logging.INFO
-            executable = self.monitoring.monitor_wrapper(executable, try_id, task_id,
-                                                         self.monitoring.monitoring_hub_url,
-                                                         self.run_id,
-                                                         wrapper_logging_level,
-                                                         self.monitoring.resource_monitoring_interval,
-                                                         executor.radio_mode,
-                                                         executor.monitor_resources(),
-                                                         self.run_dir)
+            (executable, args, kwargs) = self.monitoring.monitor_wrapper(executable, args, kwargs, try_id, task_id,
+                                                                         self.monitoring.monitoring_hub_url,
+                                                                         self.run_id,
+                                                                         wrapper_logging_level,
+                                                                         self.monitoring.resource_monitoring_interval,
+                                                                         executor.radio_mode,
+                                                                         executor.monitor_resources(),
+                                                                         self.run_dir)
 
         with self.submitter_lock:
             exec_fu = executor.submit(executable, task_record['resource_specification'], *args, **kwargs)
@@ -698,9 +700,7 @@ class DataFlowKernel(object):
                 # this is a hook for post-task stageout
                 # note that nothing depends on the output - which is maybe a bug
                 # in the not-very-tested stageout system?
-                newfunc = self.data_manager.replace_task_stage_out(f_copy, func, executor)
-                if newfunc:
-                    func = newfunc
+                func = self.data_manager.replace_task_stage_out(f_copy, func, executor)
             else:
                 logger.debug("Not performing output staging for: {}".format(repr(f)))
                 app_fut._outputs.append(DataFuture(app_fut, f, tid=app_fut.tid))
@@ -986,7 +986,7 @@ class DataFlowKernel(object):
         Parameters
         ----------
         provider: Provider obj
-           Provider for which scritps dirs are being created
+           Provider for which scripts dirs are being created
         channel: Channel obj
            Channel over which the remote dirs are to be created
         """
@@ -1066,9 +1066,7 @@ class DataFlowKernel(object):
 
         This involves releasing all resources explicitly.
 
-        If the executors are managed by the DFK, then we call scale_in on each of
-        the executors and call executor.shutdown. Otherwise, executor cleanup is left to
-        the user.
+        We call scale_in on each of the executors and call executor.shutdown.
         """
         logger.info("DFK cleanup initiated")
 
@@ -1101,7 +1099,7 @@ class DataFlowKernel(object):
         logger.info("Scaling in and shutting down executors")
 
         for executor in self.executors.values():
-            if executor.managed and not executor.bad_state_is_set:
+            if not executor.bad_state_is_set:
                 if executor.scaling_enabled:
                     logger.info(f"Scaling in executor {executor.label}")
                     job_ids = executor.provider.resources.keys()
@@ -1116,10 +1114,8 @@ class DataFlowKernel(object):
                 logger.info(f"Shutting down executor {executor.label}")
                 executor.shutdown()
                 logger.info(f"Shut down executor {executor.label}")
-            elif executor.managed and executor.bad_state_is_set:  # and bad_state_is_set
+            else:  # and bad_state_is_set
                 logger.warning(f"Not shutting down executor {executor.label} because it is in bad state")
-            else:
-                logger.info(f"Not shutting down executor {executor.label} because it is unmanaged")
 
         logger.info("Terminated executors")
         self.time_completed = datetime.datetime.now()
@@ -1159,11 +1155,11 @@ class DataFlowKernel(object):
             run under RUNDIR/checkpoints/{tasks.pkl, dfk.pkl}
         """
         with self.checkpoint_lock:
-            checkpoint_queue = None
             if tasks:
                 checkpoint_queue = tasks
             else:
-                checkpoint_queue = list(self.tasks.values())
+                checkpoint_queue = self.checkpointable_tasks
+                self.checkpointable_tasks = []
 
             checkpoint_dir = '{0}/checkpoint'.format(self.run_dir)
             checkpoint_dfk = checkpoint_dir + '/dfk.pkl'
@@ -1191,7 +1187,6 @@ class DataFlowKernel(object):
 
                     if app_fu.done() and app_fu.exception() is None:
                         hashsum = task_record['hashsum']
-                        self.wipe_task(task_id)
                         if not hashsum:
                             continue
                         t = {'hash': hashsum,
