@@ -1,3 +1,6 @@
+from typing import Sequence, Tuple
+
+
 class DataFlowException(Exception):
     """Base class for all exceptions.
 
@@ -11,11 +14,6 @@ class ConfigurationError(DataFlowException):
     """
 
 
-class DuplicateTaskError(DataFlowException):
-    """Raised by the DataFlowKernel when it finds that a job with the same task-id has been launched before.
-    """
-
-
 class BadCheckpoint(DataFlowException):
     """Error raised at the end of app execution due to missing output files.
 
@@ -27,13 +25,13 @@ class BadCheckpoint(DataFlowException):
     dependent_exceptions
     """
 
-    def __init__(self, reason):
+    def __init__(self, reason: str) -> None:
         self.reason = reason
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return self.reason
 
-    def __str__(self):
+    def __str__(self) -> str:
         return self.__repr__()
 
 
@@ -42,21 +40,14 @@ class DependencyError(DataFlowException):
        in a dependency.
 
     Args:
-         - dependent_exceptions: List of exceptions
-         - task_id: Identity of the task failed task
-
-    Contains:
-    reason (string)
-    dependent_exceptions
+         - dependent_exceptions_tids: List of dependency task IDs which failed
+         - task_id: Task ID of the task that failed because of the dependency error
     """
 
-    def __init__(self, dependent_exceptions, task_id):
-        self.dependent_exceptions = dependent_exceptions
+    def __init__(self, dependent_exceptions_tids: Sequence[Tuple[Exception, str]], task_id: int) -> None:
+        self.dependent_exceptions_tids = dependent_exceptions_tids
         self.task_id = task_id
 
-    def __repr__(self):
-        return "Dependency failure for task {} from: {}".format(self.task_id,
-                                                                self.dependent_exceptions)
-
-    def __str__(self):
-        return self.__repr__()
+    def __str__(self) -> str:
+        dep_tids = [tid for (exception, tid) in self.dependent_exceptions_tids]
+        return "Dependency failure for task {} with failed dependencies from tasks {}".format(self.task_id, dep_tids)
