@@ -4,25 +4,36 @@ from typing import Any, Callable, Dict, Optional, List
 
 from parsl.providers.provider_base import JobStatus
 
+import parsl  # noqa F401
+
 
 class ParslExecutor(metaclass=ABCMeta):
-    """Define the strict interface for all Executor classes.
+    """Executors are abstractions that represent available compute resources
+    to which you could submit arbitrary App tasks.
 
     This is a metaclass that only enforces concrete implementations of
     functionality by the child classes.
 
+    Can be used as a context manager. On exit, calls ``self.shutdown()`` with
+    no arguments and re-raises any thrown exception.
+
     In addition to the listed methods, a ParslExecutor instance must always
     have a member field:
 
        label: str - a human readable label for the executor, unique
               with respect to other executors.
 
+    Per-executor monitoring behaviour can be influenced by exposing:
+
+       radio_mode: str - a string describing which radio mode should be used to
+              send task resource data back to the submit side.
+
     An executor may optionally expose:
 
        storage_access: List[parsl.data_provider.staging.Staging] - a list of staging
               providers that will be used for file staging. In the absence of this
               attribute, or if this attribute is `None`, then a default value of
-              `parsl.data_provider.staging.default_staging` will be used by the
+              ``parsl.data_provider.staging.default_staging`` will be used by the
               staging code.
 
               Typechecker note: Ideally storage_access would be declared on executor
@@ -32,18 +43,18 @@ class ParslExecutor(metaclass=ABCMeta):
               @typeguard the constructor, you'll have to use List[Any] here.
     """
 
-    # This __init__ method exists to provide a python 3.5 compatible type declaration
-    # for the `label` attribute. If/when python 3.5 is deprecated (see parsl issue #1553)
-    # this could be replaced with a python 3.6 style attribute type declaration.
-    #   label: str
-    # and __init__ removed.
+    label: str = "undefined"
+    radio_mode: str = "udp"
+
+    def __enter__(self):
+        return self
+
+    def __exit__(self, exc_type, exc_val, exc_tb):
+        self.shutdown()
+        return False
 
     @abstractmethod
-    def __init__(self) -> None:
-        self.label = ""  # type: str
-
-    @abstractmethod
-    def start(self) -> None:
+    def start(self) -> Optional[List[str]]:
         """Start the executor.
 
         Any spin-up operations (for example: starting thread pools) should be performed here.
@@ -53,23 +64,28 @@ class ParslExecutor(metaclass=ABCMeta):
     @abstractmethod
     def submit(self, func: Callable, resource_specification: Dict[str, Any], *args: Any, **kwargs: Any) -> Future:
         """Submit.
+
+        The executor can optionally set a parsl_executor_task_id attribute on
+        the Future that it returns, and in that case, parsl will log a
+        relationship between the executor's task ID and parsl level try/task
+        IDs.
         """
         pass
 
     @abstractmethod
-    def scale_out(self, blocks: int) -> List[object]:
+    def scale_out(self, blocks: int) -> List[str]:
         """Scale out method.
 
         We should have the scale out method simply take resource object
         which will have the scaling methods, scale_out itself should be a coroutine, since
         scaling tasks can be slow.
 
-        :return: A list of job ids corresponding to the blocks that were added.
+        :return: A list of block ids corresponding to the blocks that were added.
         """
         pass
 
     @abstractmethod
-    def scale_in(self, blocks: int) -> List[object]:
+    def scale_in(self, blocks: int) -> List[str]:
         """Scale in method.
 
         Cause the executor to reduce the number of blocks by count.
@@ -78,7 +94,7 @@ class ParslExecutor(metaclass=ABCMeta):
         which will have the scaling methods, scale_in itself should be a coroutine, since
         scaling tasks can be slow.
 
-        :return: A list of job ids corresponding to the blocks that were removed.
+        :return: A list of block ids corresponding to the blocks that were removed.
         """
         pass
 
@@ -99,11 +115,28 @@ class ParslExecutor(metaclass=ABCMeta):
         """
         pass
 
+    def create_monitoring_info(self, status: Dict[str, JobStatus]) -> List[object]:
+        """Create a monitoring message for each block based on the poll status.
+
+        :return: a list of dictionaries mapping to the info of each block
+        """
+        return []
+
+    def monitor_resources(self) -> bool:
+        """Should resource monitoring happen for tasks on running on this executor?
+
+        Parsl resource monitoring conflicts with execution styles which use threads, and
+        can deadlock while running.
+
+        This function allows resource monitoring to be disabled per executor implementation.
+        """
+        return True
+
     @abstractmethod
-    def status(self) -> Dict[object, JobStatus]:
+    def status(self) -> Dict[str, JobStatus]:
         """Return the status of all jobs/blocks currently known to this executor.
 
-        :return: a dictionary mapping job ids to status strings
+        :return: a dictionary mapping block ids (in string) to job status
         """
         pass
 
@@ -116,7 +149,45 @@ class ParslExecutor(metaclass=ABCMeta):
         and this method is a delegate to the corresponding method in the provider.
 
         :return: the number of seconds to wait between calls to status() or zero if no polling
-        should be done
+                 should be done
+        """
+        pass
+
+    @property
+    @abstractmethod
+    def error_management_enabled(self) -> bool:
+        """Indicates whether worker error management is supported by this executor. Worker error
+        management is done externally to the executor. However, the executor must implement
+        certain status handling methods that allow this to function. These methods are:
+
+        :method:handle_errors
+        :method:set_bad_state_and_fail_all
+
+        The basic idea of worker error management is that an external entity maintains a view of
+        the state of the workers by calling :method:status() which is then processed to detect
+        abnormal conditions. This can be done externally, as well as internally, through
+        :method:handle_errors. If an entity external to the executor detects an abnormal condition,
+        it can notify the executor using :method:set_bad_state_and_fail_all(exception).
+
+        Some of the scaffolding needed for implementing error management inside executors,
+        including implementations for the status handling methods above, is available in
+        :class:parsl.executors.status_handling.BlockProviderExecutor, which interested executors
+        should inherit from. Noop versions of methods that are related to status handling and
+        running parsl tasks through workers are implemented by
+        :class:parsl.executors.status_handling.NoStatusHandlingExecutor.
+        """
+        pass
+
+    @abstractmethod
+    def handle_errors(self, error_handler: "parsl.dataflow.job_error_handler.JobErrorHandler",
+                      status: Dict[str, JobStatus]) -> None:
+        """This method is called by the error management infrastructure after a status poll. The
+        executor implementing this method is then responsible for detecting abnormal conditions
+        based on the status of submitted jobs. If the executor does not implement any special
+        error handling, this method should return False, in which case a generic error handling
+        scheme will be used.
+        :param error_handler: a reference to the generic error handler calling this method
+        :param status: status of all jobs launched by this executor
         """
         pass
 
