@@ -20,7 +20,7 @@ from parsl.serialize import deserialize
 
 from parsl.monitoring.message_type import MessageType
 from parsl.monitoring.types import AddressedMonitoringMessage, TaggedMonitoringMessage
-from typing import cast, Any, Callable, Optional, Union
+from typing import cast, Any, Callable, Dict, List, Optional, Union
 
 _db_manager_excepts: Optional[Exception]
 
@@ -247,8 +247,7 @@ class MonitoringHub(RepresentationMixin):
                 "The monitoring message sent from DFK to router timed-out after {}ms".format(self.dfk_channel_timeout))
 
     def close(self) -> None:
-        if self.logger:
-            self.logger.info("Terminating Monitoring Hub")
+        self.logger.info("Terminating Monitoring Hub")
         exception_msgs = []
         while True:
             try:
@@ -286,6 +285,8 @@ class MonitoringHub(RepresentationMixin):
 
     @staticmethod
     def monitor_wrapper(f: Any,
+                        args: List,
+                        kwargs: Dict,
                         try_id: int,
                         task_id: int,
                         monitoring_hub_url: str,
@@ -294,8 +295,8 @@ class MonitoringHub(RepresentationMixin):
                         sleep_dur: float,
                         radio_mode: str,
                         monitor_resources: bool,
-                        run_dir: str) -> Callable:
-        return parsl.monitoring.remote.monitor_wrapper(f, try_id, task_id, monitoring_hub_url,
+                        run_dir: str) -> Tuple[Callable, List, Dict]:
+        return parsl.monitoring.remote.monitor_wrapper(f, args, kwargs, try_id, task_id, monitoring_hub_url,
                                                        run_id, logging_level, sleep_dur, radio_mode,
                                                        monitor_resources, run_dir)
 
@@ -392,7 +393,10 @@ class MonitoringRouter:
             self.hub_port = self.sock.getsockname()[1]
         else:
             self.hub_port = hub_port
-            self.sock.bind(('0.0.0.0', self.hub_port))
+            try:
+                self.sock.bind(('0.0.0.0', self.hub_port))
+            except Exception as e:
+                raise RuntimeError(f"Could not bind to hub_port {hub_port} because: {e}")
         self.sock.settimeout(self.loop_freq / 1000)
         self.logger.info("Initialized the UDP socket on 0.0.0.0:{}".format(self.hub_port))
 
@@ -506,11 +510,9 @@ def router_starter(comm_q: "queue.Queue[Union[Tuple[int, int], str]]",
     else:
         comm_q.put((router.hub_port, router.ic_port))
 
-    router.logger.info("Starting MonitoringRouter in router_starter")
-    try:
-        router.start(priority_msgs, node_msgs, block_msgs, resource_msgs)
-    except Exception as e:
-        router.logger.exception("router.start exception")
-        exception_q.put(('Hub', str(e)))
-
-    router.logger.info("End of router_starter")
+        router.logger.info("Starting MonitoringRouter in router_starter")
+        try:
+            router.start(priority_msgs, node_msgs, block_msgs, resource_msgs)
+        except Exception as e:
+            router.logger.exception("router.start exception")
+            exception_q.put(('Hub', str(e)))
