@@ -238,10 +238,6 @@ class AdHocProvider(ExecutionProvider, RepresentationMixin):
             self.resources[job_id]['status'] = JobStatus(JobState.COMPLETED)
         return rets
 
-    @property
-    def scaling_enabled(self):
-        return True
-
     @property
     def label(self):
         return self._label
