@@ -14,18 +14,18 @@ class ClusterProvider(ExecutionProvider):
 
     Parameters
     ----------
-    label : str
+      label : str
         Label for this provider.
-    channel : Channel
+      channel : Channel
         Channel for accessing this provider. Possible channels include
         :class:`~parsl.channels.LocalChannel` (the default),
         :class:`~parsl.channels.SSHChannel`, or
         :class:`~parsl.channels.SSHInteractiveLoginChannel`.
-    walltime : str
+      walltime : str
         Walltime requested per block in HH:MM:SS.
-    launcher : str
-        FIXME
-    cmd_timeout : int
+      launcher : Launcher
+        Launcher for this provider.
+      cmd_timeout : int
         Timeout for commands made to the scheduler in seconds
 
     .. code:: python
@@ -63,7 +63,6 @@ class ClusterProvider(ExecutionProvider):
         self.min_blocks = min_blocks
         self.max_blocks = max_blocks
         self.parallelism = parallelism
-        self.provisioned_blocks = 0
         self.launcher = launcher
         self.walltime = walltime
         self.cmd_timeout = cmd_timeout
@@ -102,23 +101,22 @@ class ClusterProvider(ExecutionProvider):
 
         try:
             submit_script = Template(template).substitute(jobname=job_name, **configs)
-            # submit_script = Template(template).safe_substitute(jobname=job_name, **configs)
             with open(script_filename, 'w') as f:
                 f.write(submit_script)
 
         except KeyError as e:
             logger.error("Missing keys for submit script : %s", e)
-            raise (SchedulerMissingArgs(e.args, self.label))
+            raise SchedulerMissingArgs(e.args, self.label)
 
         except IOError as e:
             logger.error("Failed writing to submit script: %s", script_filename)
-            raise (ScriptPathError(script_filename, e))
+            raise ScriptPathError(script_filename, e)
         except Exception as e:
             print("Template : ", template)
             print("Args : ", job_name)
             print("Kwargs : ", configs)
             logger.error("Uncategorized error: %s", e)
-            raise (e)
+            raise e
 
         return True
 
@@ -144,14 +142,6 @@ class ClusterProvider(ExecutionProvider):
             self._status()
         return [self.resources[jid]['status'] for jid in job_ids]
 
-    @property
-    def current_capacity(self):
-        """ Returns the currently provisioned blocks.
-        This may need to return more information in the futures :
-        { minsize, maxsize, current_requested }
-        """
-        return self.provisioned_blocks
-
     @property
     def label(self):
         return self._label
