@@ -151,10 +151,6 @@ class CobaltProvider(ClusterProvider, RepresentationMixin):
 
         """
 
-        if self.provisioned_blocks >= self.max_blocks:
-            logger.warning("[%s] at capacity, cannot add more blocks now", self.label)
-            return None
-
         account_opt = '-A {}'.format(self.account) if self.account is not None else ''
 
         job_name = "parsl.{0}.{1}".format(job_name, time.time())
@@ -199,7 +195,7 @@ class CobaltProvider(ClusterProvider, RepresentationMixin):
             job_id = stdout.strip()
             self.resources[job_id] = {'job_id': job_id, 'status': JobStatus(JobState.PENDING)}
         else:
-            logger.error("Submission of command to scale_out failed: {0}".format(stderr))
+            logger.error("Submit command failed: {0}".format(stderr))
             raise (ScaleOutFailed(self.__class__, "Request to submit job to local scheduler failed"))
 
         logger.debug("Returning job id : {0}".format(job_id))
