@@ -17,5 +17,5 @@ config = Config(
             ),
         )
     ],
-    strategy=None,
+    strategy='none',
 )
